#ifndef __ANAPAWMODE_HH__
#define __ANAPAWMODE_HH__
#include <TObject.h>
#include <TString.h>
#include <string>
#include <list>

using namespace std;
class AnapawMode : public TObject
{
private:
  list<string> comlist;

public:
  AnapawMode();
  ~AnapawMode();
  bool ProcessLine(TString sline);
  void ShowComList();
  void AddComList(string s);
  
private:  
  bool Execute_Commandline(const TString sline);
  bool Execute_Macro(const int nword, const TString word[]);
  bool Complement_Command(int nword, TString& inp_word);
  int Split(const TString sin, TString sout[], const char *ch);
  TString WordToCintCom(const int nword, const TString word[]);
  void SetDefaultComList();

//  int Split(const TString sin, TString sout[], const TString ch);

  ClassDef(AnapawMode,0)
};
#endif
