#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ class TRint_ap;
#pragma link C++ class AnapawMode;
//#pragma link C++ class TTabCom;

#endif
